@@ -31,7 +31,7 @@ EPublisher::Config - Config module for EPublisher
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 SYNOPSIS
 
@@ -52,17 +52,6 @@ Returns the hashref build by YAML::Tiny.
 
 L<EPublisher>
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2010 Renee Baecker, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms of Artistic License 2.0.
-
-=head1 AUTHOR
-
-Renee Baecker (E<lt>module@renee-baecker.deE<gt>)
-
 =head1 AUTHOR
 
 Renee Baecker <module@renee-baecker.de>
