@@ -6,12 +6,14 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub new{
     my ($class,$args) = @_;
     my $self;
     
+    croak 'No target type given' if !$args->{type};
+
     my $plugin = 'EPublisher::Target::Plugin::' . $args->{type};
     eval{
         (my $file = $plugin) =~ s!::!/!g;
@@ -40,7 +42,7 @@ EPublisher::Target - Container for Target plugins
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 SYNOPSIS
 
@@ -52,17 +54,6 @@ version 1.26
 
 =head2 new
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2010 Renee Baecker, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms of Artistic License 2.0.
-
-=head1 AUTHOR
-
-Renee Baecker (E<lt>module@renee-baecker.deE<gt>)
-
 =head1 AUTHOR
 
 Renee Baecker <module@renee-baecker.de>
