@@ -9,9 +9,10 @@ use Carp;
 our $VERSION = 0.0101;
 
 sub new{
-    my ($class,$args) = @_;
+    my ($class,$args,%params) = @_;
     
     my $self = bless {}, $class;
+    $self->publisher( delete $params{publisher} );
     $self->_config( $args );
     
     return $self;
@@ -46,7 +47,7 @@ EPublisher::Target::Base - Base class for Target plugins
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 SYNOPSIS
 
